import { initWs } from '../ws/index.ts';
import type { ClientOptions } from 'ws';
type WSSOptions = {
  url: string;
  ws?: WebSocket;
  onConnect?: () => void;
  wsOptions?: ClientOptions;
  enabled?: boolean;
};
export class WSServer {
  ws: WebSocket;
  onConnect?: () => void;
  constructor(opts: WSSOptions) {
    this.initWs(opts);
  }
  async initWs(opts: WSSOptions) {
    const enabled = opts.enabled || true;
    if (opts.ws) {
      this.ws = opts.ws;
    } else if (enabled) {
      this.ws = await initWs(opts.url, opts.wsOptions);
    }
    this.onConnect = opts?.onConnect || (() => {});
    this.ws.onopen = this.onOpen.bind(this);
    this.ws.onmessage = this.onMessage.bind(this);
    this.ws.onerror = this.onError.bind(this);
    this.ws.onclose = this.onClose.bind(this);
  }
  async onOpen() {
    this.onConnect();
  }
  async onMessage(event: MessageEvent) {
    // console.log('WSS onMessage', event);
  }
  async onError(event: Event) {
    console.error('WSS onError');
  }
  async onClose(event: CloseEvent) {
    console.error('WSS onClose');
  }
}
